Crate verus_builtin

Crate verus_builtin 

Macros

decreases_to
decreases_to!(b => a) means that height(a) < height(b), so that b can decrease to a in decreases clauses. decreases_to!(b1, …, bn => a1, …, am) can compare lexicographically ordered values, which can be useful when making assertions about decreases clauses. Notes:
decreases_to_internal
with_triggers

Structs

FnProof
FnProof is the type of proof closures; the syntax proof_fn is used to wrap FnProof
FnSpec
Ghost
NoCopy
ProofFnConfirm
SpecChain
Tracked
int
nat
real

Constants

PROOF_FN
PROOF_FN_COPY
PROOF_FN_MUT
PROOF_FN_ONCE
PROOF_FN_SEND
PROOF_FN_SYNC

Traits

Boolean
Chainable
Decimal
IeeeFloat
IeeeFloatCast
Integer
ProofFn
ProofFnMut
ProofFnOnce
ProofFnReqEns
ProofFnReqEnsDef
SpecAdd
SpecBitAnd
SpecBitOr
SpecBitXor
SpecEq
SpecEuclideanMod
SpecEuclideanOrRealDiv
SpecMul
SpecNeg
SpecOrd
SpecShl
SpecShr
SpecSub
Structural
derive(Structural) means that exec-mode == and ghost == always yield the same result. derive(Structural) is only allowed when all the fields of a type are also Structural. derive(StructuralEq) means derive(Structural) and also implement PartialEqSpec, setting eq_spec to == and obeys_eq_spec to true.